==> python-dateparser-0.7.6-1-any.pkg.tar.xz: usr/lib/python3.8/site-packages/dateparser/data/date_translation_data/bs-Cyrl.py <==
# -*- coding: utf-8 -*-
info = {
    "name": "bs-Cyrl",
    "date_order": "DMY",
    "january": [
        "јануар",
        "јан"
    ],
    "february": [
        "фебруар",
        "феб"
    ],
    "march": [
        "март",
        "мар"
    ],
    "april": [
        "април",
        "апр"
    ],
    "may": [
        "мај"
    ],
    "june": [
        "јуни",
        "јун"
    ],
    "july": [
        "јули",
        "јул"
    ],
    "august": [
        "август",
        "авг"
    ],
    "september": [
        "септембар",
        "сеп"
    ],
    "october": [
        "октобар",
        "окт"
    ],
    "november": [
        "новембар",
        "нов"
    ],
    "december": [
        "децембар",
        "дец"
    ],
    "monday": [
        "понедељак",
        "пон"
    ],
    "tuesday": [
        "уторак",
        "уто"
    ],
    "wednesday": [
        "сриједа",
        "сри"
    ],
    "thursday": [
        "четвртак",
        "чет"
    ],
    "friday": [
        "петак",
        "пет"
    ],
    "saturday": [
        "субота",
        "суб"
    ],
    "sunday": [
        "недеља",
        "нед"
    ],
    "am": [
        "пре подне"
    ],
    "pm": [
        "поподне"
    ],
    "year": [
        "година"
    ],
    "month": [
        "месец"
    ],
    "week": [
        "недеља"
    ],
    "day": [
        "дан"
    ],
    "hour": [
        "час"
    ],
    "minute": [
        "минут"
    ],
    "second": [
        "секунд"
    ],
    "relative-type": {
        "1 year ago": [
            "прошле године"
        ],
        "0 year ago": [
            "ове године"
        ],
        "in 1 year": [
            "следеће године"
        ],
        "1 month ago": [
            "прошлог месеца"
        ],
        "0 month ago": [
            "овог месеца"
        ],
        "in 1 month": [
            "следећег месеца"
        ],
        "1 week ago": [
            "прошле недеље"
        ],
        "0 week ago": [
            "ове недеље"
        ],
        "in 1 week": [
            "следеће недеље"
        ],
        "1 day ago": [
            "јуче"
        ],
        "0 day ago": [
            "данас"
        ],
        "in 1 day": [
            "сутра"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "за (\\d+) годину",
            "за (\\d+) година"
        ],
        "\\1 year ago": [
            "пре (\\d+) годину",
            "пре (\\d+) година"
        ],
        "in \\1 month": [
            "за (\\d+) месец",
            "за (\\d+) месеци"
        ],
        "\\1 month ago": [
            "пре (\\d+) месец",
            "пре (\\d+) месеци"
        ],
        "in \\1 week": [
            "за (\\d+) недељу",
            "за (\\d+) недеља"
        ],
        "\\1 week ago": [
            "пре (\\d+) недељу",
            "пре (\\d+) недеља"
        ],
        "in \\1 day": [
            "за (\\d+) дан",
            "за (\\d+) дана"
        ],
        "\\1 day ago": [
            "пре (\\d+) дан",
            "пре (\\d+) дана"
        ],
        "in \\1 hour": [
            "за (\\d+) сат",
            "за (\\d+) сати"
        ],
        "\\1 hour ago": [
            "пре (\\d+) сат",
            "пре (\\d+) сати"
        ],
        "in \\1 minute": [
            "за (\\d+) минут",
            "за (\\d+) минута"
        ],
        "\\1 minute ago": [
            "пре (\\d+) минут",
            "пре (\\d+) минута"
        ],
        "in \\1 second": [
            "за (\\d+) секунд",
            "за (\\d+) секунди"
        ],
        "\\1 second ago": [
            "пре (\\d+) секунд",
            "пре (\\d+) секунди"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> python-dateparser-1.1.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/bs-Cyrl.py <==
info = {
    "name": "bs-Cyrl",
    "date_order": "DMY",
    "january": [
        "јан",
        "јануар"
    ],
    "february": [
        "феб",
        "фебруар"
    ],
    "march": [
        "мар",
        "март"
    ],
    "april": [
        "апр",
        "април"
    ],
    "may": [
        "мај"
    ],
    "june": [
        "јун",
        "јуни"
    ],
    "july": [
        "јул",
        "јули"
    ],
    "august": [
        "авг",
        "август"
    ],
    "september": [
        "сеп",
        "септембар"
    ],
    "october": [
        "окт",
        "октобар"
    ],
    "november": [
        "нов",
        "новембар"
    ],
    "december": [
        "дец",
        "децембар"
    ],
    "monday": [
        "пон",
        "понедељак"
    ],
    "tuesday": [
        "уто",
        "уторак"
    ],
    "wednesday": [
        "сри",
        "сриједа"
    ],
    "thursday": [
        "чет",
        "четвртак"
    ],
    "friday": [
        "пет",
        "петак"
    ],
    "saturday": [
        "суб",
        "субота"
    ],
    "sunday": [
        "нед",
        "недеља"
    ],
    "am": [
        "пре подне"
    ],
    "pm": [
        "поподне"
    ],
    "year": [
        "година"
    ],
    "month": [
        "месец"
    ],
    "week": [
        "недеља"
    ],
    "day": [
        "дан"
    ],
    "hour": [
        "час"
    ],
    "minute": [
        "минут"
    ],
    "second": [
        "секунд"
    ],
    "relative-type": {
        "0 day ago": [
            "данас"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "овог месеца"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "ове недеље"
        ],
        "0 year ago": [
            "ове године"
        ],
        "1 day ago": [
            "јуче"
        ],
        "1 month ago": [
            "прошлог месеца"
        ],
        "1 week ago": [
            "прошле недеље"
        ],
        "1 year ago": [
            "прошле године"
        ],
        "in 1 day": [
            "сутра"
        ],
        "in 1 month": [
            "следећег месеца"
        ],
        "in 1 week": [
            "следеће недеље"
        ],
        "in 1 year": [
            "следеће године"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "пре (\\d+) дан",
            "пре (\\d+) дана"
        ],
        "\\1 hour ago": [
            "пре (\\d+) сат",
            "пре (\\d+) сати"
        ],
        "\\1 minute ago": [
            "пре (\\d+) минут",
            "пре (\\d+) минута"
        ],
        "\\1 month ago": [
            "пре (\\d+) месец",
            "пре (\\d+) месеци"
        ],
        "\\1 second ago": [
            "пре (\\d+) секунд",
            "пре (\\d+) секунди"
        ],
        "\\1 week ago": [
            "пре (\\d+) недеља",
            "пре (\\d+) недељу"
        ],
        "\\1 year ago": [
            "пре (\\d+) година",
            "пре (\\d+) годину"
        ],
        "in \\1 day": [
            "за (\\d+) дан",
            "за (\\d+) дана"
        ],
        "in \\1 hour": [
            "за (\\d+) сат",
            "за (\\d+) сати"
        ],
        "in \\1 minute": [
            "за (\\d+) минут",
            "за (\\d+) минута"
        ],
        "in \\1 month": [
            "за (\\d+) месец",
            "за (\\d+) месеци"
        ],
        "in \\1 second": [
            "за (\\d+) секунд",
            "за (\\d+) секунди"
        ],
        "in \\1 week": [
            "за (\\d+) недеља",
            "за (\\d+) недељу"
        ],
        "in \\1 year": [
            "за (\\d+) година",
            "за (\\d+) годину"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
